@@ -185,7 +185,7 @@ class Player:
             discord=Discord.from_dict(obj.get("Discord")) if "Discord" in obj else None,
             fc_information=FriendCodeHandler.from_dict(obj.get("FCs")) if "FCs" in obj else None,
             names=from_list(lambda x: Name.from_dict(x), obj.get("N")),
-            pronoun=Pronoun.from_dict(obj.get("Pro")),
+            pronoun=Pronoun.from_dict(obj.get("Pro")) if "Pro" in obj else None,
             plus_membership=from_list(lambda x: PlusMembership.from_dict(x), obj.get("Plus")),
             sendou_profiles=from_list(lambda x: Sendou.from_dict(x), obj.get("Sendou")),
             skill=Skill.from_dict(obj.get("Skill")) if "Skill" in obj else Skill(),
@@ -213,7 +213,7 @@ class Player:
             result["N"] = to_list(lambda x: Name.to_dict(x), self.names)
         if len(self.plus_membership) > 0:
             result["Plus"] = to_list(lambda x: PlusMembership.to_dict(x), self.plus_membership)
-        if self.pronoun:
+        if self.pronoun and self.pronoun.value:
             result["Pro"] = self.pronoun.to_dict()
         if len(self.sendou_profiles) > 0:
             result["Sendou"] = to_list(lambda x: Sendou.to_dict(x), self.sendou_profiles)
