@@ -101,7 +101,7 @@ def deserialize_uuids(info: Mapping,
                         fn: Callable[[Any], UUID] = mapping[1]
                         uuids.append(fn(s))
                         continue
-                logging.error(f"Could not convert s into UUID ({s=})")
+                logging.error(f"Could not convert s into UUID with {key=}, {s=}")
         except ValueError as e:
             logging.error(f"ERROR in deserialize_uuids: {info=} with {key=}", exc_info=e)
     return uuids
@@ -132,5 +132,6 @@ def key_value_list_to_dict(kv_list: List[tuple]) -> Dict[Any, list]:
     """
     d = {}
     for k, v in kv_list:
+        # DefaultDict
         d.setdefault(k, []).append(v)
     return d
