@@ -66,7 +66,7 @@ class SimpleSource:
     @staticmethod
     @functools.cache
     def initialise(source_name: Optional[str]) -> Tuple[Optional[str], Optional[str], Optional[str], Optional[str]]:
-        """Initialise the simple source's (date, organiser, tournament name, url)."""
+        """Initialise the simple sources's (date, organiser, tournament name, url)."""
         if not source_name:
             return None, None, None, None
 
@@ -79,7 +79,7 @@ class SimpleSource:
 
         id_at_the_end_match = TOURNAMENT_ID_REGEX.search(source_name)
         if id_at_the_end_match:
-            # We always want to grab the last match as the id is at the end of the source name.
+            # We always want to grab the last match as the id is at the end of the sources name.
             tournament_id = id_at_the_end_match.groups()[-1]
             default_tourney_name = TOURNAMENT_ID_REGEX.sub('', default_tourney_name, count=1)
         else:
@@ -100,7 +100,7 @@ class SimpleSource:
             return date, None, tournament_name, tournament_id
 
     def get_linked_date_display(self) -> str:
-        """Return a markdown link with the truncated source date if available,
+        """Return a markdown link with the truncated sources date if available,
         otherwise return its truncated_name only."""
         link = self.url
         if self.date:
@@ -110,7 +110,7 @@ class SimpleSource:
         return f"[{text}]({link})" if link else text
 
     def get_linked_name_display(self) -> str:
-        """Return a markdown link with the truncated source name (date-name) if available,
+        """Return a markdown link with the truncated sources name (date-name) if available,
         otherwise return its truncated_name only."""
         link = self.url
         text = self.truncated_name
@@ -118,7 +118,7 @@ class SimpleSource:
 
     @property
     def truncated_name(self):
-        """The source with the id removed and truncated down."""
+        """The sources with the id removed and truncated down."""
         if self.date and self.tournament_name:
             display_name = self.date + '-' + self.tournament_name
         else:
